from django_ansi2html_filter.templatetags.ansi import ansi, ansi_styles
import unittest
from unittest import TestCase


def load_suite():
    test_suite = unittest.TestSuite()
    return test_suite


class ANSIEscapeConversionTestCase(TestCase):
    def test_colour_escape(self):
        escaped = "\x1b[32mFetching project\x1b[0m"
        html = ansi(escaped)
        expected = "<span class=\"ansi32\">Fetching project</span>"
        self.assertEqual(html, expected)

    def test_keep_quotes(self):
        escaped = "Getting 'something'"
        html = ansi(escaped)
        expected = "Getting 'something'"
        self.assertEqual(html, expected)


class StyleGenerationTestCase(TestCase):
    def test_style_generation(self):
        html = ansi_styles()
        expected = ".body_foreground { color: #AAAAAA; }\n.body_background { background-color: #000000; }\n.body_foreground > .bold,.bold > .body_foreground, body.body_foreground > pre > .bold { color: #FFFFFF; font-weight: normal; }\n.inv_foreground { color: #000000; }\n.inv_background { background-color: #AAAAAA; }\n.ansi1 { font-weight: bold; }\n.ansi2 { font-weight: lighter; }\n.ansi3 { font-style: italic; }\n.ansi4 { text-decoration: underline; }\n.ansi5 { text-decoration: blink; }\n.ansi6 { text-decoration: blink; }\n.ansi8 { visibility: hidden; }\n.ansi9 { text-decoration: line-through; }\n.ansi30 { color: #262626; }\n.inv30 { background-color: #262626; }\n.ansi31 { color: #d70000; }\n.inv31 { background-color: #d70000; }\n.ansi32 { color: #5f8700; }\n.inv32 { background-color: #5f8700; }\n.ansi33 { color: #af8700; }\n.inv33 { background-color: #af8700; }\n.ansi34 { color: #0087ff; }\n.inv34 { background-color: #0087ff; }\n.ansi35 { color: #af005f; }\n.inv35 { background-color: #af005f; }\n.ansi36 { color: #00afaf; }\n.inv36 { background-color: #00afaf; }\n.ansi37 { color: #e4e4e4; }\n.inv37 { background-color: #e4e4e4; }\n.ansi40 { background-color: #262626; }\n.inv40 { color: #262626; }\n.ansi41 { background-color: #d70000; }\n.inv41 { color: #d70000; }\n.ansi42 { background-color: #5f8700; }\n.inv42 { color: #5f8700; }\n.ansi43 { background-color: #af8700; }\n.inv43 { color: #af8700; }\n.ansi44 { background-color: #0087ff; }\n.inv44 { color: #0087ff; }\n.ansi45 { background-color: #af005f; }\n.inv45 { color: #af005f; }\n.ansi46 { background-color: #00afaf; }\n.inv46 { color: #00afaf; }\n.ansi47 { background-color: #e4e4e4; }\n.inv47 { color: #e4e4e4; }\n.ansi38-16 { color: #000000; }\n.inv38-16 { background: #000000; }\n.ansi48-16 { background: #000000; }\n.inv48-16 { color: #000000; }\n.ansi38-17 { color: #00002a; }\n.inv38-17 { background: #00002a; }\n.ansi48-17 { background: #00002a; }\n.inv48-17 { color: #00002a; }\n.ansi38-18 { color: #000054; }\n.inv38-18 { background: #000054; }\n.ansi48-18 { background: #000054; }\n.inv48-18 { color: #000054; }\n.ansi38-19 { color: #00007e; }\n.inv38-19 { background: #00007e; }\n.ansi48-19 { background: #00007e; }\n.inv48-19 { color: #00007e; }\n.ansi38-20 { color: #0000a8; }\n.inv38-20 { background: #0000a8; }\n.ansi48-20 { background: #0000a8; }\n.inv48-20 { color: #0000a8; }\n.ansi38-21 { color: #0000d2; }\n.inv38-21 { background: #0000d2; }\n.ansi48-21 { background: #0000d2; }\n.inv48-21 { color: #0000d2; }\n.ansi38-52 { color: #2a0000; }\n.inv38-52 { background: #2a0000; }\n.ansi48-52 { background: #2a0000; }\n.inv48-52 { color: #2a0000; }\n.ansi38-53 { color: #2a002a; }\n.inv38-53 { background: #2a002a; }\n.ansi48-53 { background: #2a002a; }\n.inv48-53 { color: #2a002a; }\n.ansi38-54 { color: #2a0054; }\n.inv38-54 { background: #2a0054; }\n.ansi48-54 { background: #2a0054; }\n.inv48-54 { color: #2a0054; }\n.ansi38-55 { color: #2a007e; }\n.inv38-55 { background: #2a007e; }\n.ansi48-55 { background: #2a007e; }\n.inv48-55 { color: #2a007e; }\n.ansi38-56 { color: #2a00a8; }\n.inv38-56 { background: #2a00a8; }\n.ansi48-56 { background: #2a00a8; }\n.inv48-56 { color: #2a00a8; }\n.ansi38-57 { color: #2a00d2; }\n.inv38-57 { background: #2a00d2; }\n.ansi48-57 { background: #2a00d2; }\n.inv48-57 { color: #2a00d2; }\n.ansi38-88 { color: #540000; }\n.inv38-88 { background: #540000; }\n.ansi48-88 { background: #540000; }\n.inv48-88 { color: #540000; }\n.ansi38-89 { color: #54002a; }\n.inv38-89 { background: #54002a; }\n.ansi48-89 { background: #54002a; }\n.inv48-89 { color: #54002a; }\n.ansi38-90 { color: #540054; }\n.inv38-90 { background: #540054; }\n.ansi48-90 { background: #540054; }\n.inv48-90 { color: #540054; }\n.ansi38-91 { color: #54007e; }\n.inv38-91 { background: #54007e; }\n.ansi48-91 { background: #54007e; }\n.inv48-91 { color: #54007e; }\n.ansi38-92 { color: #5400a8; }\n.inv38-92 { background: #5400a8; }\n.ansi48-92 { background: #5400a8; }\n.inv48-92 { color: #5400a8; }\n.ansi38-93 { color: #5400d2; }\n.inv38-93 { background: #5400d2; }\n.ansi48-93 { background: #5400d2; }\n.inv48-93 { color: #5400d2; }\n.ansi38-124 { color: #7e0000; }\n.inv38-124 { background: #7e0000; }\n.ansi48-124 { background: #7e0000; }\n.inv48-124 { color: #7e0000; }\n.ansi38-125 { color: #7e002a; }\n.inv38-125 { background: #7e002a; }\n.ansi48-125 { background: #7e002a; }\n.inv48-125 { color: #7e002a; }\n.ansi38-126 { color: #7e0054; }\n.inv38-126 { background: #7e0054; }\n.ansi48-126 { background: #7e0054; }\n.inv48-126 { color: #7e0054; }\n.ansi38-127 { color: #7e007e; }\n.inv38-127 { background: #7e007e; }\n.ansi48-127 { background: #7e007e; }\n.inv48-127 { color: #7e007e; }\n.ansi38-128 { color: #7e00a8; }\n.inv38-128 { background: #7e00a8; }\n.ansi48-128 { background: #7e00a8; }\n.inv48-128 { color: #7e00a8; }\n.ansi38-129 { color: #7e00d2; }\n.inv38-129 { background: #7e00d2; }\n.ansi48-129 { background: #7e00d2; }\n.inv48-129 { color: #7e00d2; }\n.ansi38-160 { color: #a80000; }\n.inv38-160 { background: #a80000; }\n.ansi48-160 { background: #a80000; }\n.inv48-160 { color: #a80000; }\n.ansi38-161 { color: #a8002a; }\n.inv38-161 { background: #a8002a; }\n.ansi48-161 { background: #a8002a; }\n.inv48-161 { color: #a8002a; }\n.ansi38-162 { color: #a80054; }\n.inv38-162 { background: #a80054; }\n.ansi48-162 { background: #a80054; }\n.inv48-162 { color: #a80054; }\n.ansi38-163 { color: #a8007e; }\n.inv38-163 { background: #a8007e; }\n.ansi48-163 { background: #a8007e; }\n.inv48-163 { color: #a8007e; }\n.ansi38-164 { color: #a800a8; }\n.inv38-164 { background: #a800a8; }\n.ansi48-164 { background: #a800a8; }\n.inv48-164 { color: #a800a8; }\n.ansi38-165 { color: #a800d2; }\n.inv38-165 { background: #a800d2; }\n.ansi48-165 { background: #a800d2; }\n.inv48-165 { color: #a800d2; }\n.ansi38-196 { color: #d20000; }\n.inv38-196 { background: #d20000; }\n.ansi48-196 { background: #d20000; }\n.inv48-196 { color: #d20000; }\n.ansi38-197 { color: #d2002a; }\n.inv38-197 { background: #d2002a; }\n.ansi48-197 { background: #d2002a; }\n.inv48-197 { color: #d2002a; }\n.ansi38-198 { color: #d20054; }\n.inv38-198 { background: #d20054; }\n.ansi48-198 { background: #d20054; }\n.inv48-198 { color: #d20054; }\n.ansi38-199 { color: #d2007e; }\n.inv38-199 { background: #d2007e; }\n.ansi48-199 { background: #d2007e; }\n.inv48-199 { color: #d2007e; }\n.ansi38-200 { color: #d200a8; }\n.inv38-200 { background: #d200a8; }\n.ansi48-200 { background: #d200a8; }\n.inv48-200 { color: #d200a8; }\n.ansi38-201 { color: #d200d2; }\n.inv38-201 { background: #d200d2; }\n.ansi48-201 { background: #d200d2; }\n.inv48-201 { color: #d200d2; }\n.ansi38-22 { color: #002a00; }\n.inv38-22 { background: #002a00; }\n.ansi48-22 { background: #002a00; }\n.inv48-22 { color: #002a00; }\n.ansi38-23 { color: #002a2a; }\n.inv38-23 { background: #002a2a; }\n.ansi48-23 { background: #002a2a; }\n.inv48-23 { color: #002a2a; }\n.ansi38-24 { color: #002a54; }\n.inv38-24 { background: #002a54; }\n.ansi48-24 { background: #002a54; }\n.inv48-24 { color: #002a54; }\n.ansi38-25 { color: #002a7e; }\n.inv38-25 { background: #002a7e; }\n.ansi48-25 { background: #002a7e; }\n.inv48-25 { color: #002a7e; }\n.ansi38-26 { color: #002aa8; }\n.inv38-26 { background: #002aa8; }\n.ansi48-26 { background: #002aa8; }\n.inv48-26 { color: #002aa8; }\n.ansi38-27 { color: #002ad2; }\n.inv38-27 { background: #002ad2; }\n.ansi48-27 { background: #002ad2; }\n.inv48-27 { color: #002ad2; }\n.ansi38-58 { color: #2a2a00; }\n.inv38-58 { background: #2a2a00; }\n.ansi48-58 { background: #2a2a00; }\n.inv48-58 { color: #2a2a00; }\n.ansi38-59 { color: #2a2a2a; }\n.inv38-59 { background: #2a2a2a; }\n.ansi48-59 { background: #2a2a2a; }\n.inv48-59 { color: #2a2a2a; }\n.ansi38-60 { color: #2a2a54; }\n.inv38-60 { background: #2a2a54; }\n.ansi48-60 { background: #2a2a54; }\n.inv48-60 { color: #2a2a54; }\n.ansi38-61 { color: #2a2a7e; }\n.inv38-61 { background: #2a2a7e; }\n.ansi48-61 { background: #2a2a7e; }\n.inv48-61 { color: #2a2a7e; }\n.ansi38-62 { color: #2a2aa8; }\n.inv38-62 { background: #2a2aa8; }\n.ansi48-62 { background: #2a2aa8; }\n.inv48-62 { color: #2a2aa8; }\n.ansi38-63 { color: #2a2ad2; }\n.inv38-63 { background: #2a2ad2; }\n.ansi48-63 { background: #2a2ad2; }\n.inv48-63 { color: #2a2ad2; }\n.ansi38-94 { color: #542a00; }\n.inv38-94 { background: #542a00; }\n.ansi48-94 { background: #542a00; }\n.inv48-94 { color: #542a00; }\n.ansi38-95 { color: #542a2a; }\n.inv38-95 { background: #542a2a; }\n.ansi48-95 { background: #542a2a; }\n.inv48-95 { color: #542a2a; }\n.ansi38-96 { color: #542a54; }\n.inv38-96 { background: #542a54; }\n.ansi48-96 { background: #542a54; }\n.inv48-96 { color: #542a54; }\n.ansi38-97 { color: #542a7e; }\n.inv38-97 { background: #542a7e; }\n.ansi48-97 { background: #542a7e; }\n.inv48-97 { color: #542a7e; }\n.ansi38-98 { color: #542aa8; }\n.inv38-98 { background: #542aa8; }\n.ansi48-98 { background: #542aa8; }\n.inv48-98 { color: #542aa8; }\n.ansi38-99 { color: #542ad2; }\n.inv38-99 { background: #542ad2; }\n.ansi48-99 { background: #542ad2; }\n.inv48-99 { color: #542ad2; }\n.ansi38-130 { color: #7e2a00; }\n.inv38-130 { background: #7e2a00; }\n.ansi48-130 { background: #7e2a00; }\n.inv48-130 { color: #7e2a00; }\n.ansi38-131 { color: #7e2a2a; }\n.inv38-131 { background: #7e2a2a; }\n.ansi48-131 { background: #7e2a2a; }\n.inv48-131 { color: #7e2a2a; }\n.ansi38-132 { color: #7e2a54; }\n.inv38-132 { background: #7e2a54; }\n.ansi48-132 { background: #7e2a54; }\n.inv48-132 { color: #7e2a54; }\n.ansi38-133 { color: #7e2a7e; }\n.inv38-133 { background: #7e2a7e; }\n.ansi48-133 { background: #7e2a7e; }\n.inv48-133 { color: #7e2a7e; }\n.ansi38-134 { color: #7e2aa8; }\n.inv38-134 { background: #7e2aa8; }\n.ansi48-134 { background: #7e2aa8; }\n.inv48-134 { color: #7e2aa8; }\n.ansi38-135 { color: #7e2ad2; }\n.inv38-135 { background: #7e2ad2; }\n.ansi48-135 { background: #7e2ad2; }\n.inv48-135 { color: #7e2ad2; }\n.ansi38-166 { color: #a82a00; }\n.inv38-166 { background: #a82a00; }\n.ansi48-166 { background: #a82a00; }\n.inv48-166 { color: #a82a00; }\n.ansi38-167 { color: #a82a2a; }\n.inv38-167 { background: #a82a2a; }\n.ansi48-167 { background: #a82a2a; }\n.inv48-167 { color: #a82a2a; }\n.ansi38-168 { color: #a82a54; }\n.inv38-168 { background: #a82a54; }\n.ansi48-168 { background: #a82a54; }\n.inv48-168 { color: #a82a54; }\n.ansi38-169 { color: #a82a7e; }\n.inv38-169 { background: #a82a7e; }\n.ansi48-169 { background: #a82a7e; }\n.inv48-169 { color: #a82a7e; }\n.ansi38-170 { color: #a82aa8; }\n.inv38-170 { background: #a82aa8; }\n.ansi48-170 { background: #a82aa8; }\n.inv48-170 { color: #a82aa8; }\n.ansi38-171 { color: #a82ad2; }\n.inv38-171 { background: #a82ad2; }\n.ansi48-171 { background: #a82ad2; }\n.inv48-171 { color: #a82ad2; }\n.ansi38-202 { color: #d22a00; }\n.inv38-202 { background: #d22a00; }\n.ansi48-202 { background: #d22a00; }\n.inv48-202 { color: #d22a00; }\n.ansi38-203 { color: #d22a2a; }\n.inv38-203 { background: #d22a2a; }\n.ansi48-203 { background: #d22a2a; }\n.inv48-203 { color: #d22a2a; }\n.ansi38-204 { color: #d22a54; }\n.inv38-204 { background: #d22a54; }\n.ansi48-204 { background: #d22a54; }\n.inv48-204 { color: #d22a54; }\n.ansi38-205 { color: #d22a7e; }\n.inv38-205 { background: #d22a7e; }\n.ansi48-205 { background: #d22a7e; }\n.inv48-205 { color: #d22a7e; }\n.ansi38-206 { color: #d22aa8; }\n.inv38-206 { background: #d22aa8; }\n.ansi48-206 { background: #d22aa8; }\n.inv48-206 { color: #d22aa8; }\n.ansi38-207 { color: #d22ad2; }\n.inv38-207 { background: #d22ad2; }\n.ansi48-207 { background: #d22ad2; }\n.inv48-207 { color: #d22ad2; }\n.ansi38-28 { color: #005400; }\n.inv38-28 { background: #005400; }\n.ansi48-28 { background: #005400; }\n.inv48-28 { color: #005400; }\n.ansi38-29 { color: #00542a; }\n.inv38-29 { background: #00542a; }\n.ansi48-29 { background: #00542a; }\n.inv48-29 { color: #00542a; }\n.ansi38-30 { color: #005454; }\n.inv38-30 { background: #005454; }\n.ansi48-30 { background: #005454; }\n.inv48-30 { color: #005454; }\n.ansi38-31 { color: #00547e; }\n.inv38-31 { background: #00547e; }\n.ansi48-31 { background: #00547e; }\n.inv48-31 { color: #00547e; }\n.ansi38-32 { color: #0054a8; }\n.inv38-32 { background: #0054a8; }\n.ansi48-32 { background: #0054a8; }\n.inv48-32 { color: #0054a8; }\n.ansi38-33 { color: #0054d2; }\n.inv38-33 { background: #0054d2; }\n.ansi48-33 { background: #0054d2; }\n.inv48-33 { color: #0054d2; }\n.ansi38-64 { color: #2a5400; }\n.inv38-64 { background: #2a5400; }\n.ansi48-64 { background: #2a5400; }\n.inv48-64 { color: #2a5400; }\n.ansi38-65 { color: #2a542a; }\n.inv38-65 { background: #2a542a; }\n.ansi48-65 { background: #2a542a; }\n.inv48-65 { color: #2a542a; }\n.ansi38-66 { color: #2a5454; }\n.inv38-66 { background: #2a5454; }\n.ansi48-66 { background: #2a5454; }\n.inv48-66 { color: #2a5454; }\n.ansi38-67 { color: #2a547e; }\n.inv38-67 { background: #2a547e; }\n.ansi48-67 { background: #2a547e; }\n.inv48-67 { color: #2a547e; }\n.ansi38-68 { color: #2a54a8; }\n.inv38-68 { background: #2a54a8; }\n.ansi48-68 { background: #2a54a8; }\n.inv48-68 { color: #2a54a8; }\n.ansi38-69 { color: #2a54d2; }\n.inv38-69 { background: #2a54d2; }\n.ansi48-69 { background: #2a54d2; }\n.inv48-69 { color: #2a54d2; }\n.ansi38-100 { color: #545400; }\n.inv38-100 { background: #545400; }\n.ansi48-100 { background: #545400; }\n.inv48-100 { color: #545400; }\n.ansi38-101 { color: #54542a; }\n.inv38-101 { background: #54542a; }\n.ansi48-101 { background: #54542a; }\n.inv48-101 { color: #54542a; }\n.ansi38-102 { color: #545454; }\n.inv38-102 { background: #545454; }\n.ansi48-102 { background: #545454; }\n.inv48-102 { color: #545454; }\n.ansi38-103 { color: #54547e; }\n.inv38-103 { background: #54547e; }\n.ansi48-103 { background: #54547e; }\n.inv48-103 { color: #54547e; }\n.ansi38-104 { color: #5454a8; }\n.inv38-104 { background: #5454a8; }\n.ansi48-104 { background: #5454a8; }\n.inv48-104 { color: #5454a8; }\n.ansi38-105 { color: #5454d2; }\n.inv38-105 { background: #5454d2; }\n.ansi48-105 { background: #5454d2; }\n.inv48-105 { color: #5454d2; }\n.ansi38-136 { color: #7e5400; }\n.inv38-136 { background: #7e5400; }\n.ansi48-136 { background: #7e5400; }\n.inv48-136 { color: #7e5400; }\n.ansi38-137 { color: #7e542a; }\n.inv38-137 { background: #7e542a; }\n.ansi48-137 { background: #7e542a; }\n.inv48-137 { color: #7e542a; }\n.ansi38-138 { color: #7e5454; }\n.inv38-138 { background: #7e5454; }\n.ansi48-138 { background: #7e5454; }\n.inv48-138 { color: #7e5454; }\n.ansi38-139 { color: #7e547e; }\n.inv38-139 { background: #7e547e; }\n.ansi48-139 { background: #7e547e; }\n.inv48-139 { color: #7e547e; }\n.ansi38-140 { color: #7e54a8; }\n.inv38-140 { background: #7e54a8; }\n.ansi48-140 { background: #7e54a8; }\n.inv48-140 { color: #7e54a8; }\n.ansi38-141 { color: #7e54d2; }\n.inv38-141 { background: #7e54d2; }\n.ansi48-141 { background: #7e54d2; }\n.inv48-141 { color: #7e54d2; }\n.ansi38-172 { color: #a85400; }\n.inv38-172 { background: #a85400; }\n.ansi48-172 { background: #a85400; }\n.inv48-172 { color: #a85400; }\n.ansi38-173 { color: #a8542a; }\n.inv38-173 { background: #a8542a; }\n.ansi48-173 { background: #a8542a; }\n.inv48-173 { color: #a8542a; }\n.ansi38-174 { color: #a85454; }\n.inv38-174 { background: #a85454; }\n.ansi48-174 { background: #a85454; }\n.inv48-174 { color: #a85454; }\n.ansi38-175 { color: #a8547e; }\n.inv38-175 { background: #a8547e; }\n.ansi48-175 { background: #a8547e; }\n.inv48-175 { color: #a8547e; }\n.ansi38-176 { color: #a854a8; }\n.inv38-176 { background: #a854a8; }\n.ansi48-176 { background: #a854a8; }\n.inv48-176 { color: #a854a8; }\n.ansi38-177 { color: #a854d2; }\n.inv38-177 { background: #a854d2; }\n.ansi48-177 { background: #a854d2; }\n.inv48-177 { color: #a854d2; }\n.ansi38-208 { color: #d25400; }\n.inv38-208 { background: #d25400; }\n.ansi48-208 { background: #d25400; }\n.inv48-208 { color: #d25400; }\n.ansi38-209 { color: #d2542a; }\n.inv38-209 { background: #d2542a; }\n.ansi48-209 { background: #d2542a; }\n.inv48-209 { color: #d2542a; }\n.ansi38-210 { color: #d25454; }\n.inv38-210 { background: #d25454; }\n.ansi48-210 { background: #d25454; }\n.inv48-210 { color: #d25454; }\n.ansi38-211 { color: #d2547e; }\n.inv38-211 { background: #d2547e; }\n.ansi48-211 { background: #d2547e; }\n.inv48-211 { color: #d2547e; }\n.ansi38-212 { color: #d254a8; }\n.inv38-212 { background: #d254a8; }\n.ansi48-212 { background: #d254a8; }\n.inv48-212 { color: #d254a8; }\n.ansi38-213 { color: #d254d2; }\n.inv38-213 { background: #d254d2; }\n.ansi48-213 { background: #d254d2; }\n.inv48-213 { color: #d254d2; }\n.ansi38-34 { color: #007e00; }\n.inv38-34 { background: #007e00; }\n.ansi48-34 { background: #007e00; }\n.inv48-34 { color: #007e00; }\n.ansi38-35 { color: #007e2a; }\n.inv38-35 { background: #007e2a; }\n.ansi48-35 { background: #007e2a; }\n.inv48-35 { color: #007e2a; }\n.ansi38-36 { color: #007e54; }\n.inv38-36 { background: #007e54; }\n.ansi48-36 { background: #007e54; }\n.inv48-36 { color: #007e54; }\n.ansi38-37 { color: #007e7e; }\n.inv38-37 { background: #007e7e; }\n.ansi48-37 { background: #007e7e; }\n.inv48-37 { color: #007e7e; }\n.ansi38-38 { color: #007ea8; }\n.inv38-38 { background: #007ea8; }\n.ansi48-38 { background: #007ea8; }\n.inv48-38 { color: #007ea8; }\n.ansi38-39 { color: #007ed2; }\n.inv38-39 { background: #007ed2; }\n.ansi48-39 { background: #007ed2; }\n.inv48-39 { color: #007ed2; }\n.ansi38-70 { color: #2a7e00; }\n.inv38-70 { background: #2a7e00; }\n.ansi48-70 { background: #2a7e00; }\n.inv48-70 { color: #2a7e00; }\n.ansi38-71 { color: #2a7e2a; }\n.inv38-71 { background: #2a7e2a; }\n.ansi48-71 { background: #2a7e2a; }\n.inv48-71 { color: #2a7e2a; }\n.ansi38-72 { color: #2a7e54; }\n.inv38-72 { background: #2a7e54; }\n.ansi48-72 { background: #2a7e54; }\n.inv48-72 { color: #2a7e54; }\n.ansi38-73 { color: #2a7e7e; }\n.inv38-73 { background: #2a7e7e; }\n.ansi48-73 { background: #2a7e7e; }\n.inv48-73 { color: #2a7e7e; }\n.ansi38-74 { color: #2a7ea8; }\n.inv38-74 { background: #2a7ea8; }\n.ansi48-74 { background: #2a7ea8; }\n.inv48-74 { color: #2a7ea8; }\n.ansi38-75 { color: #2a7ed2; }\n.inv38-75 { background: #2a7ed2; }\n.ansi48-75 { background: #2a7ed2; }\n.inv48-75 { color: #2a7ed2; }\n.ansi38-106 { color: #547e00; }\n.inv38-106 { background: #547e00; }\n.ansi48-106 { background: #547e00; }\n.inv48-106 { color: #547e00; }\n.ansi38-107 { color: #547e2a; }\n.inv38-107 { background: #547e2a; }\n.ansi48-107 { background: #547e2a; }\n.inv48-107 { color: #547e2a; }\n.ansi38-108 { color: #547e54; }\n.inv38-108 { background: #547e54; }\n.ansi48-108 { background: #547e54; }\n.inv48-108 { color: #547e54; }\n.ansi38-109 { color: #547e7e; }\n.inv38-109 { background: #547e7e; }\n.ansi48-109 { background: #547e7e; }\n.inv48-109 { color: #547e7e; }\n.ansi38-110 { color: #547ea8; }\n.inv38-110 { background: #547ea8; }\n.ansi48-110 { background: #547ea8; }\n.inv48-110 { color: #547ea8; }\n.ansi38-111 { color: #547ed2; }\n.inv38-111 { background: #547ed2; }\n.ansi48-111 { background: #547ed2; }\n.inv48-111 { color: #547ed2; }\n.ansi38-142 { color: #7e7e00; }\n.inv38-142 { background: #7e7e00; }\n.ansi48-142 { background: #7e7e00; }\n.inv48-142 { color: #7e7e00; }\n.ansi38-143 { color: #7e7e2a; }\n.inv38-143 { background: #7e7e2a; }\n.ansi48-143 { background: #7e7e2a; }\n.inv48-143 { color: #7e7e2a; }\n.ansi38-144 { color: #7e7e54; }\n.inv38-144 { background: #7e7e54; }\n.ansi48-144 { background: #7e7e54; }\n.inv48-144 { color: #7e7e54; }\n.ansi38-145 { color: #7e7e7e; }\n.inv38-145 { background: #7e7e7e; }\n.ansi48-145 { background: #7e7e7e; }\n.inv48-145 { color: #7e7e7e; }\n.ansi38-146 { color: #7e7ea8; }\n.inv38-146 { background: #7e7ea8; }\n.ansi48-146 { background: #7e7ea8; }\n.inv48-146 { color: #7e7ea8; }\n.ansi38-147 { color: #7e7ed2; }\n.inv38-147 { background: #7e7ed2; }\n.ansi48-147 { background: #7e7ed2; }\n.inv48-147 { color: #7e7ed2; }\n.ansi38-178 { color: #a87e00; }\n.inv38-178 { background: #a87e00; }\n.ansi48-178 { background: #a87e00; }\n.inv48-178 { color: #a87e00; }\n.ansi38-179 { color: #a87e2a; }\n.inv38-179 { background: #a87e2a; }\n.ansi48-179 { background: #a87e2a; }\n.inv48-179 { color: #a87e2a; }\n.ansi38-180 { color: #a87e54; }\n.inv38-180 { background: #a87e54; }\n.ansi48-180 { background: #a87e54; }\n.inv48-180 { color: #a87e54; }\n.ansi38-181 { color: #a87e7e; }\n.inv38-181 { background: #a87e7e; }\n.ansi48-181 { background: #a87e7e; }\n.inv48-181 { color: #a87e7e; }\n.ansi38-182 { color: #a87ea8; }\n.inv38-182 { background: #a87ea8; }\n.ansi48-182 { background: #a87ea8; }\n.inv48-182 { color: #a87ea8; }\n.ansi38-183 { color: #a87ed2; }\n.inv38-183 { background: #a87ed2; }\n.ansi48-183 { background: #a87ed2; }\n.inv48-183 { color: #a87ed2; }\n.ansi38-214 { color: #d27e00; }\n.inv38-214 { background: #d27e00; }\n.ansi48-214 { background: #d27e00; }\n.inv48-214 { color: #d27e00; }\n.ansi38-215 { color: #d27e2a; }\n.inv38-215 { background: #d27e2a; }\n.ansi48-215 { background: #d27e2a; }\n.inv48-215 { color: #d27e2a; }\n.ansi38-216 { color: #d27e54; }\n.inv38-216 { background: #d27e54; }\n.ansi48-216 { background: #d27e54; }\n.inv48-216 { color: #d27e54; }\n.ansi38-217 { color: #d27e7e; }\n.inv38-217 { background: #d27e7e; }\n.ansi48-217 { background: #d27e7e; }\n.inv48-217 { color: #d27e7e; }\n.ansi38-218 { color: #d27ea8; }\n.inv38-218 { background: #d27ea8; }\n.ansi48-218 { background: #d27ea8; }\n.inv48-218 { color: #d27ea8; }\n.ansi38-219 { color: #d27ed2; }\n.inv38-219 { background: #d27ed2; }\n.ansi48-219 { background: #d27ed2; }\n.inv48-219 { color: #d27ed2; }\n.ansi38-40 { color: #00a800; }\n.inv38-40 { background: #00a800; }\n.ansi48-40 { background: #00a800; }\n.inv48-40 { color: #00a800; }\n.ansi38-41 { color: #00a82a; }\n.inv38-41 { background: #00a82a; }\n.ansi48-41 { background: #00a82a; }\n.inv48-41 { color: #00a82a; }\n.ansi38-42 { color: #00a854; }\n.inv38-42 { background: #00a854; }\n.ansi48-42 { background: #00a854; }\n.inv48-42 { color: #00a854; }\n.ansi38-43 { color: #00a87e; }\n.inv38-43 { background: #00a87e; }\n.ansi48-43 { background: #00a87e; }\n.inv48-43 { color: #00a87e; }\n.ansi38-44 { color: #00a8a8; }\n.inv38-44 { background: #00a8a8; }\n.ansi48-44 { background: #00a8a8; }\n.inv48-44 { color: #00a8a8; }\n.ansi38-45 { color: #00a8d2; }\n.inv38-45 { background: #00a8d2; }\n.ansi48-45 { background: #00a8d2; }\n.inv48-45 { color: #00a8d2; }\n.ansi38-76 { color: #2aa800; }\n.inv38-76 { background: #2aa800; }\n.ansi48-76 { background: #2aa800; }\n.inv48-76 { color: #2aa800; }\n.ansi38-77 { color: #2aa82a; }\n.inv38-77 { background: #2aa82a; }\n.ansi48-77 { background: #2aa82a; }\n.inv48-77 { color: #2aa82a; }\n.ansi38-78 { color: #2aa854; }\n.inv38-78 { background: #2aa854; }\n.ansi48-78 { background: #2aa854; }\n.inv48-78 { color: #2aa854; }\n.ansi38-79 { color: #2aa87e; }\n.inv38-79 { background: #2aa87e; }\n.ansi48-79 { background: #2aa87e; }\n.inv48-79 { color: #2aa87e; }\n.ansi38-80 { color: #2aa8a8; }\n.inv38-80 { background: #2aa8a8; }\n.ansi48-80 { background: #2aa8a8; }\n.inv48-80 { color: #2aa8a8; }\n.ansi38-81 { color: #2aa8d2; }\n.inv38-81 { background: #2aa8d2; }\n.ansi48-81 { background: #2aa8d2; }\n.inv48-81 { color: #2aa8d2; }\n.ansi38-112 { color: #54a800; }\n.inv38-112 { background: #54a800; }\n.ansi48-112 { background: #54a800; }\n.inv48-112 { color: #54a800; }\n.ansi38-113 { color: #54a82a; }\n.inv38-113 { background: #54a82a; }\n.ansi48-113 { background: #54a82a; }\n.inv48-113 { color: #54a82a; }\n.ansi38-114 { color: #54a854; }\n.inv38-114 { background: #54a854; }\n.ansi48-114 { background: #54a854; }\n.inv48-114 { color: #54a854; }\n.ansi38-115 { color: #54a87e; }\n.inv38-115 { background: #54a87e; }\n.ansi48-115 { background: #54a87e; }\n.inv48-115 { color: #54a87e; }\n.ansi38-116 { color: #54a8a8; }\n.inv38-116 { background: #54a8a8; }\n.ansi48-116 { background: #54a8a8; }\n.inv48-116 { color: #54a8a8; }\n.ansi38-117 { color: #54a8d2; }\n.inv38-117 { background: #54a8d2; }\n.ansi48-117 { background: #54a8d2; }\n.inv48-117 { color: #54a8d2; }\n.ansi38-148 { color: #7ea800; }\n.inv38-148 { background: #7ea800; }\n.ansi48-148 { background: #7ea800; }\n.inv48-148 { color: #7ea800; }\n.ansi38-149 { color: #7ea82a; }\n.inv38-149 { background: #7ea82a; }\n.ansi48-149 { background: #7ea82a; }\n.inv48-149 { color: #7ea82a; }\n.ansi38-150 { color: #7ea854; }\n.inv38-150 { background: #7ea854; }\n.ansi48-150 { background: #7ea854; }\n.inv48-150 { color: #7ea854; }\n.ansi38-151 { color: #7ea87e; }\n.inv38-151 { background: #7ea87e; }\n.ansi48-151 { background: #7ea87e; }\n.inv48-151 { color: #7ea87e; }\n.ansi38-152 { color: #7ea8a8; }\n.inv38-152 { background: #7ea8a8; }\n.ansi48-152 { background: #7ea8a8; }\n.inv48-152 { color: #7ea8a8; }\n.ansi38-153 { color: #7ea8d2; }\n.inv38-153 { background: #7ea8d2; }\n.ansi48-153 { background: #7ea8d2; }\n.inv48-153 { color: #7ea8d2; }\n.ansi38-184 { color: #a8a800; }\n.inv38-184 { background: #a8a800; }\n.ansi48-184 { background: #a8a800; }\n.inv48-184 { color: #a8a800; }\n.ansi38-185 { color: #a8a82a; }\n.inv38-185 { background: #a8a82a; }\n.ansi48-185 { background: #a8a82a; }\n.inv48-185 { color: #a8a82a; }\n.ansi38-186 { color: #a8a854; }\n.inv38-186 { background: #a8a854; }\n.ansi48-186 { background: #a8a854; }\n.inv48-186 { color: #a8a854; }\n.ansi38-187 { color: #a8a87e; }\n.inv38-187 { background: #a8a87e; }\n.ansi48-187 { background: #a8a87e; }\n.inv48-187 { color: #a8a87e; }\n.ansi38-188 { color: #a8a8a8; }\n.inv38-188 { background: #a8a8a8; }\n.ansi48-188 { background: #a8a8a8; }\n.inv48-188 { color: #a8a8a8; }\n.ansi38-189 { color: #a8a8d2; }\n.inv38-189 { background: #a8a8d2; }\n.ansi48-189 { background: #a8a8d2; }\n.inv48-189 { color: #a8a8d2; }\n.ansi38-220 { color: #d2a800; }\n.inv38-220 { background: #d2a800; }\n.ansi48-220 { background: #d2a800; }\n.inv48-220 { color: #d2a800; }\n.ansi38-221 { color: #d2a82a; }\n.inv38-221 { background: #d2a82a; }\n.ansi48-221 { background: #d2a82a; }\n.inv48-221 { color: #d2a82a; }\n.ansi38-222 { color: #d2a854; }\n.inv38-222 { background: #d2a854; }\n.ansi48-222 { background: #d2a854; }\n.inv48-222 { color: #d2a854; }\n.ansi38-223 { color: #d2a87e; }\n.inv38-223 { background: #d2a87e; }\n.ansi48-223 { background: #d2a87e; }\n.inv48-223 { color: #d2a87e; }\n.ansi38-224 { color: #d2a8a8; }\n.inv38-224 { background: #d2a8a8; }\n.ansi48-224 { background: #d2a8a8; }\n.inv48-224 { color: #d2a8a8; }\n.ansi38-225 { color: #d2a8d2; }\n.inv38-225 { background: #d2a8d2; }\n.ansi48-225 { background: #d2a8d2; }\n.inv48-225 { color: #d2a8d2; }\n.ansi38-46 { color: #00d200; }\n.inv38-46 { background: #00d200; }\n.ansi48-46 { background: #00d200; }\n.inv48-46 { color: #00d200; }\n.ansi38-47 { color: #00d22a; }\n.inv38-47 { background: #00d22a; }\n.ansi48-47 { background: #00d22a; }\n.inv48-47 { color: #00d22a; }\n.ansi38-48 { color: #00d254; }\n.inv38-48 { background: #00d254; }\n.ansi48-48 { background: #00d254; }\n.inv48-48 { color: #00d254; }\n.ansi38-49 { color: #00d27e; }\n.inv38-49 { background: #00d27e; }\n.ansi48-49 { background: #00d27e; }\n.inv48-49 { color: #00d27e; }\n.ansi38-50 { color: #00d2a8; }\n.inv38-50 { background: #00d2a8; }\n.ansi48-50 { background: #00d2a8; }\n.inv48-50 { color: #00d2a8; }\n.ansi38-51 { color: #00d2d2; }\n.inv38-51 { background: #00d2d2; }\n.ansi48-51 { background: #00d2d2; }\n.inv48-51 { color: #00d2d2; }\n.ansi38-82 { color: #2ad200; }\n.inv38-82 { background: #2ad200; }\n.ansi48-82 { background: #2ad200; }\n.inv48-82 { color: #2ad200; }\n.ansi38-83 { color: #2ad22a; }\n.inv38-83 { background: #2ad22a; }\n.ansi48-83 { background: #2ad22a; }\n.inv48-83 { color: #2ad22a; }\n.ansi38-84 { color: #2ad254; }\n.inv38-84 { background: #2ad254; }\n.ansi48-84 { background: #2ad254; }\n.inv48-84 { color: #2ad254; }\n.ansi38-85 { color: #2ad27e; }\n.inv38-85 { background: #2ad27e; }\n.ansi48-85 { background: #2ad27e; }\n.inv48-85 { color: #2ad27e; }\n.ansi38-86 { color: #2ad2a8; }\n.inv38-86 { background: #2ad2a8; }\n.ansi48-86 { background: #2ad2a8; }\n.inv48-86 { color: #2ad2a8; }\n.ansi38-87 { color: #2ad2d2; }\n.inv38-87 { background: #2ad2d2; }\n.ansi48-87 { background: #2ad2d2; }\n.inv48-87 { color: #2ad2d2; }\n.ansi38-118 { color: #54d200; }\n.inv38-118 { background: #54d200; }\n.ansi48-118 { background: #54d200; }\n.inv48-118 { color: #54d200; }\n.ansi38-119 { color: #54d22a; }\n.inv38-119 { background: #54d22a; }\n.ansi48-119 { background: #54d22a; }\n.inv48-119 { color: #54d22a; }\n.ansi38-120 { color: #54d254; }\n.inv38-120 { background: #54d254; }\n.ansi48-120 { background: #54d254; }\n.inv48-120 { color: #54d254; }\n.ansi38-121 { color: #54d27e; }\n.inv38-121 { background: #54d27e; }\n.ansi48-121 { background: #54d27e; }\n.inv48-121 { color: #54d27e; }\n.ansi38-122 { color: #54d2a8; }\n.inv38-122 { background: #54d2a8; }\n.ansi48-122 { background: #54d2a8; }\n.inv48-122 { color: #54d2a8; }\n.ansi38-123 { color: #54d2d2; }\n.inv38-123 { background: #54d2d2; }\n.ansi48-123 { background: #54d2d2; }\n.inv48-123 { color: #54d2d2; }\n.ansi38-154 { color: #7ed200; }\n.inv38-154 { background: #7ed200; }\n.ansi48-154 { background: #7ed200; }\n.inv48-154 { color: #7ed200; }\n.ansi38-155 { color: #7ed22a; }\n.inv38-155 { background: #7ed22a; }\n.ansi48-155 { background: #7ed22a; }\n.inv48-155 { color: #7ed22a; }\n.ansi38-156 { color: #7ed254; }\n.inv38-156 { background: #7ed254; }\n.ansi48-156 { background: #7ed254; }\n.inv48-156 { color: #7ed254; }\n.ansi38-157 { color: #7ed27e; }\n.inv38-157 { background: #7ed27e; }\n.ansi48-157 { background: #7ed27e; }\n.inv48-157 { color: #7ed27e; }\n.ansi38-158 { color: #7ed2a8; }\n.inv38-158 { background: #7ed2a8; }\n.ansi48-158 { background: #7ed2a8; }\n.inv48-158 { color: #7ed2a8; }\n.ansi38-159 { color: #7ed2d2; }\n.inv38-159 { background: #7ed2d2; }\n.ansi48-159 { background: #7ed2d2; }\n.inv48-159 { color: #7ed2d2; }\n.ansi38-190 { color: #a8d200; }\n.inv38-190 { background: #a8d200; }\n.ansi48-190 { background: #a8d200; }\n.inv48-190 { color: #a8d200; }\n.ansi38-191 { color: #a8d22a; }\n.inv38-191 { background: #a8d22a; }\n.ansi48-191 { background: #a8d22a; }\n.inv48-191 { color: #a8d22a; }\n.ansi38-192 { color: #a8d254; }\n.inv38-192 { background: #a8d254; }\n.ansi48-192 { background: #a8d254; }\n.inv48-192 { color: #a8d254; }\n.ansi38-193 { color: #a8d27e; }\n.inv38-193 { background: #a8d27e; }\n.ansi48-193 { background: #a8d27e; }\n.inv48-193 { color: #a8d27e; }\n.ansi38-194 { color: #a8d2a8; }\n.inv38-194 { background: #a8d2a8; }\n.ansi48-194 { background: #a8d2a8; }\n.inv48-194 { color: #a8d2a8; }\n.ansi38-195 { color: #a8d2d2; }\n.inv38-195 { background: #a8d2d2; }\n.ansi48-195 { background: #a8d2d2; }\n.inv48-195 { color: #a8d2d2; }\n.ansi38-226 { color: #d2d200; }\n.inv38-226 { background: #d2d200; }\n.ansi48-226 { background: #d2d200; }\n.inv48-226 { color: #d2d200; }\n.ansi38-227 { color: #d2d22a; }\n.inv38-227 { background: #d2d22a; }\n.ansi48-227 { background: #d2d22a; }\n.inv48-227 { color: #d2d22a; }\n.ansi38-228 { color: #d2d254; }\n.inv38-228 { background: #d2d254; }\n.ansi48-228 { background: #d2d254; }\n.inv48-228 { color: #d2d254; }\n.ansi38-229 { color: #d2d27e; }\n.inv38-229 { background: #d2d27e; }\n.ansi48-229 { background: #d2d27e; }\n.inv48-229 { color: #d2d27e; }\n.ansi38-230 { color: #d2d2a8; }\n.inv38-230 { background: #d2d2a8; }\n.ansi48-230 { background: #d2d2a8; }\n.inv48-230 { color: #d2d2a8; }\n.ansi38-231 { color: #d2d2d2; }\n.inv38-231 { background: #d2d2d2; }\n.ansi48-231 { background: #d2d2d2; }\n.inv48-231 { color: #d2d2d2; }\n.ansi38-232 { color: #080808; }\n.inv38-232 { background: #080808; }\n.ansi48-232 { background: #080808; }\n.inv48-232 { color: #080808; }\n.ansi38-233 { color: #121212; }\n.inv38-233 { background: #121212; }\n.ansi48-233 { background: #121212; }\n.inv48-233 { color: #121212; }\n.ansi38-234 { color: #1c1c1c; }\n.inv38-234 { background: #1c1c1c; }\n.ansi48-234 { background: #1c1c1c; }\n.inv48-234 { color: #1c1c1c; }\n.ansi38-235 { color: #262626; }\n.inv38-235 { background: #262626; }\n.ansi48-235 { background: #262626; }\n.inv48-235 { color: #262626; }\n.ansi38-236 { color: #303030; }\n.inv38-236 { background: #303030; }\n.ansi48-236 { background: #303030; }\n.inv48-236 { color: #303030; }\n.ansi38-237 { color: #3a3a3a; }\n.inv38-237 { background: #3a3a3a; }\n.ansi48-237 { background: #3a3a3a; }\n.inv48-237 { color: #3a3a3a; }\n.ansi38-238 { color: #444444; }\n.inv38-238 { background: #444444; }\n.ansi48-238 { background: #444444; }\n.inv48-238 { color: #444444; }\n.ansi38-239 { color: #4e4e4e; }\n.inv38-239 { background: #4e4e4e; }\n.ansi48-239 { background: #4e4e4e; }\n.inv48-239 { color: #4e4e4e; }\n.ansi38-240 { color: #585858; }\n.inv38-240 { background: #585858; }\n.ansi48-240 { background: #585858; }\n.inv48-240 { color: #585858; }\n.ansi38-241 { color: #626262; }\n.inv38-241 { background: #626262; }\n.ansi48-241 { background: #626262; }\n.inv48-241 { color: #626262; }\n.ansi38-242 { color: #6c6c6c; }\n.inv38-242 { background: #6c6c6c; }\n.ansi48-242 { background: #6c6c6c; }\n.inv48-242 { color: #6c6c6c; }\n.ansi38-243 { color: #767676; }\n.inv38-243 { background: #767676; }\n.ansi48-243 { background: #767676; }\n.inv48-243 { color: #767676; }\n.ansi38-244 { color: #808080; }\n.inv38-244 { background: #808080; }\n.ansi48-244 { background: #808080; }\n.inv48-244 { color: #808080; }\n.ansi38-245 { color: #8a8a8a; }\n.inv38-245 { background: #8a8a8a; }\n.ansi48-245 { background: #8a8a8a; }\n.inv48-245 { color: #8a8a8a; }\n.ansi38-246 { color: #949494; }\n.inv38-246 { background: #949494; }\n.ansi48-246 { background: #949494; }\n.inv48-246 { color: #949494; }\n.ansi38-247 { color: #9e9e9e; }\n.inv38-247 { background: #9e9e9e; }\n.ansi48-247 { background: #9e9e9e; }\n.inv48-247 { color: #9e9e9e; }\n.ansi38-248 { color: #a8a8a8; }\n.inv38-248 { background: #a8a8a8; }\n.ansi48-248 { background: #a8a8a8; }\n.inv48-248 { color: #a8a8a8; }\n.ansi38-249 { color: #b2b2b2; }\n.inv38-249 { background: #b2b2b2; }\n.ansi48-249 { background: #b2b2b2; }\n.inv48-249 { color: #b2b2b2; }\n.ansi38-250 { color: #bcbcbc; }\n.inv38-250 { background: #bcbcbc; }\n.ansi48-250 { background: #bcbcbc; }\n.inv48-250 { color: #bcbcbc; }\n.ansi38-251 { color: #c6c6c6; }\n.inv38-251 { background: #c6c6c6; }\n.ansi48-251 { background: #c6c6c6; }\n.inv48-251 { color: #c6c6c6; }\n.ansi38-252 { color: #d0d0d0; }\n.inv38-252 { background: #d0d0d0; }\n.ansi48-252 { background: #d0d0d0; }\n.inv48-252 { color: #d0d0d0; }\n.ansi38-253 { color: #dadada; }\n.inv38-253 { background: #dadada; }\n.ansi48-253 { background: #dadada; }\n.inv48-253 { color: #dadada; }\n.ansi38-254 { color: #e4e4e4; }\n.inv38-254 { background: #e4e4e4; }\n.ansi48-254 { background: #e4e4e4; }\n.inv48-254 { color: #e4e4e4; }\n.ansi38-255 { color: #eeeeee; }\n.inv38-255 { background: #eeeeee; }\n.ansi48-255 { background: #eeeeee; }\n.inv48-255 { color: #eeeeee; }"
        self.assertEqual(html, expected)
